HealthDataType enum

Enumeration of supported health data types for querying health information.

This enum defines the various types of health data that can be requested and retrieved from health platforms like HealthKit (iOS) or Health Connect (Android).

Inheritance
Available extensions

Values

stepCount → const HealthDataType

Step count data - number of steps taken

const HealthDataType('stepCount')

Properties

hashCode int
The hash code for this object.
no setterinherited
identifier String
The string identifier used for platform communication
final
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<HealthDataType>
A constant List of the values in this enum, in order of their declaration.